@@ -9,7 +9,16 @@ from singer.utils import (
     update_state,
 )
 
-from singer.logger import get_logger
+from singer.logger import (
+    get_logger,
+    log_debug,
+    log_info,
+    log_warning,
+    log_error,
+    log_critical,
+    log_fatal,
+    log_exception,
+)
 
 from singer.metrics import (
     Counter,
